/*
 * CentralizedChat.java
 *
 * Created on March 7, 2005, 7:39 AM
 */
package ch.epfl.lpd.ids;

import ch.epfl.lpd.ids.server.*;
import ch.epfl.lpd.ids.serialization.*;
import ch.epfl.lpd.ids.client.*;

/**
 * CentralizedChat class used to start the local chat.  This class
 * starts the server and the two different chat clients.
 * 
 * @author Sebastien Baehni
 */
public class CentralizedChat  {
    
    /**
     * The different chat clients.
     */
    protected IChatClient firstClient;
    protected IChatClient secondClient;
  
    /**
     * Creates a new instance of CentralizedChat.  This implies
     * creating the instance of the ChatServer as the two instances of
     * ChatClient.
     */
    public CentralizedChat() {
        IServer server = new ChatServer();
        this.firstClient = new ChatClient(server);
        this.secondClient = new ChatClient(server);
    }
    
    /**
     * The main method of the class. This method is the entry point of
     * the local chat application.
     * @param args The arguments given when launching the application
     * (not used)
     */
    public static void main(String[] args) {
        CentralizedChat cChat = new CentralizedChat();
        cChat.firstClient.connect("Client 1");
        cChat.firstClient.sendMessage(new Message("header 1", "message 1".getBytes()));
        cChat.secondClient.connect("Client 2");
        cChat.secondClient.sendMessage(new MyMessage("header 2", "message 2".getBytes()));
        cChat.firstClient.disconnect();
        cChat.secondClient.disconnect();
    }
    
}
