package ch.epfl.lpd.ids.client;

import ch.epfl.lpd.ids.server.IServer;
import ch.epfl.lpd.ids.serialization.*;

/**
 * This class represents a chat client. 
 * @author Sebastien Baehni
 */
public class ChatClient implements IChatClient {
    
    /**
     * The reference to the {@link
     * ch.epfl.lpd.ids.server.IServer}. This reference will be used to
     * send messages, connect and disconnect.
     */

    protected IServer server;

    /**
     * The username of this chat client.
     */
    protected String username = "";

    /**
     * Boolean used to check is this client is connected to the server
     * or not.
     */
    protected boolean connected = false;
    
    /**
     * Creates a new instance of ChatClient.
     * @param server The {@link ch.epfl.lpd.ids.server.IServer} reference.
     */
    public ChatClient(IServer server) {        
        this.server = server;
    }
    
    /**
     * Method called when
     * the user wants to connect to the server. This method calls the
     * <CODE>connect()</CODE> method on the {@link
     * ch.epfl.lpd.ids.server.IServer}
     * @param username The username of the client.
     * @return True if the client was able to connect, false otherwise.
     */
    public boolean connect(String username) {
        if (!connected) {
            boolean result = this.server.connect(username);
            if (result) {
                this.connected = true;
                this.username = username;
                System.out.println(this.username + " is connected.");
            }
            else {
                System.out.println(username + " is already connected.");
            }
            return result;
        }
        else {
            System.out.println(this.username + " is already connected.");
            return false;
        }
    }
    
    /**
     * Method called when
     * the user wants to disconnect from the {@link
     * ch.epfl.lpd.ids.server.IServer}.
     * @return True if the client was successfully disconnected, false
     * otherwise.
     */
    public boolean disconnect() {
        if (connected) {
            this.connected = false;
            boolean result = this.server.disconnect(this.username);
            if (result) {                
                System.out.println(this.username + " is disconnected.");
            }
            else {
                this.connected = true;
            }
            return result;
        }
        else {
            System.out.println(this.username + " is already disconnected.");
            return false;
        }
    }
    
    /**
     * Method called when the user wants to send a message to the chat
     * server. This method send a {@link
     * ch.epfl.lpd.ids.serialization.IMessage} to the server.
     * @param message The message as a IMessage.
     */
    public void sendMessage(IMessage message) {
        if (connected) {
            this.server.sendMessage(this.username,message);
        }
    }
    
}
