package ch.epfl.lpd.ids.server;

import java.util.Vector;

import ch.epfl.lpd.ids.serialization.*;

/**
 * This class represents the chat server. The server manages a list of
 * connected chat clients and is able to receive messages from those
 * clients. Moreover, the clients can get a list of the connected
 * clients from this server
 * @author Sebastien Baehni
 */
public class ChatServer implements IServer {
    
    /**
     * A {@link java.util.Vector} of {@link
     * ch.epfl.lpd.ids.server.InternalClients}.
     */
    Vector<String> clients;
    
    /**
     * Creates a new instance of ChatServer and initialize the {@link
     * java.util.Vector} of {@link
     * ch.epfl.lpd.ids.server.InternalClient}.
     */
    public ChatServer() {
        this.clients = new Vector<String>();
    }
    
    /**
     * Method called by a client to connect to this server.
     * @param username The username of the client.
     * @return True if the connection was possible (i.e., no client
     * with the same provided username is already connected), false
     * otherwise.
     */
    public boolean connect(String username) {
        if (this.clients.contains(username)) {
            return false;
        }
        this.clients.add(username);
        return true;
    }
    
    /**
     * Method called by a client to disconnect from this server.
     * @param username The username of the chat client that wants to
     * be disconnected.
     * @return True if the chat client was able to disconnect from
     * this server, false otherwise.
     */
    public boolean disconnect(String username) {
        if (this.clients.contains(username)) {
            this.clients.remove(username);
            return true;
        }
        return false;        
    }
    
    /**
     * Method called by the chat client to send the messages to this
     * server. It simply outputs the message on the standard output.
     * @param username The username of the client that is sending the
     * message.
     * @param msg The {@link ch.epfl.lpd.ids.serialization.IMessage}
     * sends from the client to the server.
     */
    public void sendMessage(String username, IMessage msg) {
	if (this.clients.contains(username)) 
	    System.out.println("Message received: "+msg);
    }
    
}
